From c4634b06aaf66c8540cf9fe6f272658cb94ffd31 Mon Sep 17 00:00:00 2001
From: Ariel Barria <olivares73@hotmail.com>
Date: Wed, 3 Apr 2013 14:57:46 -0500
Subject: [PATCH] Confusing error messages for invalid sssd.conf

https://fedorahosted.org/sssd/ticket/1625

Amending errors messages and add other error codes to be more specific
and avoid confusion.
---
 src/monitor/monitor.c | 23 ++++++++++++++---------
 1 file changed, 14 insertions(+), 9 deletions(-)

diff --git a/src/monitor/monitor.c b/src/monitor/monitor.c
index 7a543908f131e3ea302979171372f4970a419b60..d4bef01e9fe6c96b1a473462e8201761ea8d0152 100644
--- a/src/monitor/monitor.c
+++ b/src/monitor/monitor.c
@@ -2767,17 +2767,22 @@ int main(int argc, const char *argv[])
     /* Parse config file, fail if cannot be done */
     ret = load_configuration(tmp_ctx, config_file, &monitor);
     if (ret != EOK) {
-        if (ret == EPERM) {
-            DEBUG(1, ("Cannot read configuration file %s\n", config_file));
+        switch (ret) {
+        case EPERM:
+            DEBUG(SSSDBG_CRIT_FAILURE,
+                 ("Not enough permission to read configuration file.\n"));
+            break;
+        case EACCES:
+            DEBUG(SSSDBG_CRIT_FAILURE,
+                 ("Not enough permission to read configuration file.\n"));
+            break;
+        default:
+            DEBUG(SSSDBG_CRIT_FAILURE,
+                 ("SSSD couldn't load the configuration database.\n"));
             sss_log(SSS_LOG_ALERT,
-                    "Cannot read config file %s, please check if permissions "
-                    "are 0600 and the file is owned by root.root", config_file);
-        } else {
-            DEBUG(SSSDBG_CRIT_FAILURE, ("Error loading configuration database: "
-                                        "[%d]: %s\n", ret, strerror(ret)));
-            sss_log(SSS_LOG_ALERT,
-                    "Cannot load configuration database: [%d]: %s",
+                   "SSSD couldn't load the configuration database [%d]: %s.\n",
                     ret, strerror(ret));
+            break;
         }
         return 4;
     }
-- 
1.8.1.4

